@@ -6,10 +6,10 @@ import pytest
 
 from kombu import Producer
 
-from nameko import consuming
 from nameko import context
 from nameko import entities
 from nameko import sending
+from nameko.consuming import queue_iterator
 from nameko.responses import ifirst
 
 
@@ -17,13 +17,12 @@ def test_replying(connection):
     with connection as conn:
         msgid = uuid.uuid4().hex
         with conn.channel() as chan:
-            queue = entities.get_reply_queue(msgid=msgid,
-                    channel=chan)
+            queue = entities.get_reply_queue(msgid=msgid, channel=chan)
             queue.declare()
 
             sending.reply(conn, msgid, 'success')
-            msg = ifirst(consuming.queue_iterator(queue, no_ack=True,
-                timeout=0.2))
+            msg = ifirst(queue_iterator(
+                queue, no_ack=True, timeout=0.2))
             assert msg.payload['result'] == 'success'
 
 
@@ -36,15 +35,11 @@ def test_send_direct(connection):
     with connection as conn:
         msgid = uuid.uuid4().hex
         with conn.channel() as chan:
-            queue = entities.get_reply_queue(msgid=msgid,
-                    channel=chan)
+            queue = entities.get_reply_queue(msgid=msgid, channel=chan)
             queue.declare()
 
-            sending.send_direct(conn,
-                    directid=msgid,
-                    data='success')
-            msg = ifirst(consuming.queue_iterator(queue, no_ack=True,
-                timeout=0.2))
+            sending.send_direct(conn, directid=msgid, data='success')
+            msg = ifirst(queue_iterator(queue, no_ack=True, timeout=0.2))
             assert msg.payload == 'success'
 
 
@@ -54,12 +49,12 @@ def test_send_topic(connection):
             queue = entities.get_topic_queue('test_rpc', 'test', channel=chan)
             queue.declare()
 
-            sending.send_topic(conn,
-                    exchange='test_rpc',
-                    topic='test',
-                    data='success')
-            msg = ifirst(consuming.queue_iterator(queue, no_ack=True,
-                timeout=0.2))
+            sending.send_topic(
+                conn,
+                exchange='test_rpc',
+                topic='test',
+                data='success')
+            msg = ifirst(queue_iterator(queue, no_ack=True, timeout=0.2))
             assert msg.payload == 'success'
 
 
@@ -69,7 +64,8 @@ def test_send_topic_using_send_rpc(connection):
             queue = entities.get_topic_queue('test_rpc', 'test', channel=chan)
             queue.declare()
             ctx = context.get_admin_context()
-            sending.send_rpc(conn,
+            sending.send_rpc(
+                conn,
                 context=ctx,
                 exchange='test_rpc',
                 topic='test',
@@ -78,8 +74,7 @@ def test_send_topic_using_send_rpc(connection):
                 timeout=3,
                 noreply=True)
 
-            msg = ifirst(consuming.queue_iterator(queue, no_ack=True,
-                timeout=0.2))
+            msg = ifirst(queue_iterator(queue, no_ack=True, timeout=0.2))
             expected = {'args': {'foo': 'bar'}, 'method': 'test_method'}
             ctx.add_to_message(expected)
             assert msg.payload == expected
@@ -91,11 +86,11 @@ def test_send_fanout(connection):
             queue = entities.get_fanout_queue('test', channel=chan)
             queue.declare()
 
-            sending.send_fanout(conn,
-                    topic='test',
-                    data='success')
-            msg = ifirst(consuming.queue_iterator(queue, no_ack=True,
-                timeout=0.2))
+            sending.send_fanout(
+                conn,
+                topic='test',
+                data='success')
+            msg = ifirst(queue_iterator(queue, no_ack=True, timeout=0.2))
             assert msg.payload == 'success'
 
 
@@ -105,7 +100,8 @@ def test_send_fanout_using_send_rpc(connection):
             queue = entities.get_fanout_queue('test', channel=chan)
             queue.declare()
             ctx = context.get_admin_context()
-            sending.send_rpc(conn,
+            sending.send_rpc(
+                conn,
                 context=ctx,
                 exchange='test_rpc',
                 topic='test',
@@ -114,8 +110,7 @@ def test_send_fanout_using_send_rpc(connection):
                 timeout=3,
                 fanout=True)
 
-            msg = ifirst(consuming.queue_iterator(queue, no_ack=True,
-                timeout=0.2))
+            msg = ifirst(queue_iterator(queue, no_ack=True, timeout=0.2))
             expected = {'args': {'foo': 'bar'}, 'method': 'test_method'}
             ctx.add_to_message(expected)
             assert msg.payload == expected
@@ -125,11 +120,10 @@ def test_send_rpc(get_connection):
     def response_greenthread():
         with get_connection() as conn:
             with conn.channel() as chan:
-                queue = entities.get_topic_queue('test_rpc', 'test',
-                    channel=chan)
+                queue = entities.get_topic_queue(
+                    'test_rpc', 'test', channel=chan)
                 queue.declare()
-                msg = ifirst(consuming.queue_iterator(queue, no_ack=True,
-                    timeout=2))
+                msg = ifirst(queue_iterator(queue, no_ack=True, timeout=2))
                 msgid, ctx, method, args = context.parse_message(msg.payload)
                 sending.reply(conn, msgid, args)
 
@@ -138,7 +132,8 @@ def test_send_rpc(get_connection):
 
     with get_connection() as conn:
         ctx = context.get_admin_context()
-        resp = sending.send_rpc(conn,
+        resp = sending.send_rpc(
+            conn,
             context=ctx,
             exchange='test_rpc',
             topic='test',
@@ -155,19 +150,19 @@ def test_send_rpc_multi_message_reply_ignores_all_but_last(get_connection):
     def response_greenthread():
         with get_connection() as conn:
             with conn.channel() as chan:
-                queue = entities.get_topic_queue('test_rpc', 'test',
-                    channel=chan)
+                queue = entities.get_topic_queue(
+                    'test_rpc', 'test', channel=chan)
                 queue.declare()
 
-                msg = ifirst(consuming.queue_iterator(queue, no_ack=True,
-                    timeout=2))
+                msg = ifirst(queue_iterator(queue, no_ack=True, timeout=2))
                 msgid, ctx, method, args = context.parse_message(msg.payload)
 
                 exchange = entities.get_reply_exchange(msgid)
                 producer = Producer(chan, exchange=exchange, routing_key=msgid)
 
                 for _ in range(3):
-                    msg = dict(result='should ignore this message',
+                    msg = dict(
+                        result='should ignore this message',
                         failure=None, ending=False)
                     producer.publish(msg)
                     eventlet.sleep(0.1)
@@ -182,7 +177,8 @@ def test_send_rpc_multi_message_reply_ignores_all_but_last(get_connection):
 
     with get_connection() as conn:
         ctx = context.get_admin_context()
-        resp = sending.send_rpc(conn,
+        resp = sending.send_rpc(
+            conn,
             context=ctx,
             exchange='test_rpc',
             topic='test',
